@@ -28,7 +28,7 @@ try:
 except ImportError:
     pass
 
-__version__ = '0.9.7'
+__version__ = '0.9.8'
 __version_info__ = __version__.split('.')
 
 CTPP2_VERSION = (2, 6)
@@ -48,7 +48,7 @@ def extract_i18n_messages(fileobj, keywords, comment_tags, options):
     """
     string = r'(([^"]|(\"))+?)'
     pattern = r"""
-        <TMPL_var\s+(_|GETTEXT)\s*
+        (_|GETTEXT)\s*
         [(]\s*
         " %s ((")|$)""" % string
     regexp = re.compile(pattern, re.IGNORECASE|re.VERBOSE)
